Struct WpCommitTimingManagerV1

pub struct WpCommitTimingManagerV1 { /* private fields */ }
Available on crate feature wayland and Linux only.
commit timing

When a compositor latches on to new content updates it will check for any number of requirements of the available content updates (such as fences of all buffers being signalled) to consider the update ready.

This protocol provides a method for adding a time constraint to surface content. This constraint indicates to the compositor that a content update should be presented as closely as possible to, but not before, a specified time.

This protocol does not change the Wayland property that content updates are applied in the order they are received, even when some content updates contain timestamps and others do not.

To provide timestamps, this global factory interface must be used to acquire a wp_commit_timing_v1 object for a surface, which may then be used to provide timestamp information for commits.

Warning! The protocol described in this file is currently in the testing phase. Backward compatible changes may be added together with the corresponding interface version bump. Backward incompatible changes can only be done by creating a new major version of the extension.

This interface has no events.

Implementations



impl WpCommitTimingManagerV1

pub fn destroy(&self)

unbind from the commit timing interface

Informs the server that the client will no longer be using this protocol object. Existing objects created by this object are not affected.

pub fn get_timer<U, D>( &self, surface: &WlSurface, qh: &QueueHandle<D>, udata: U, ) -> WpCommitTimerV1
where U: Send + Sync + 'static, D: Dispatch<WpCommitTimerV1, U> + 'static,

request commit timer interface for surface

Establish a timing controller for a surface.

Only one commit timer can be created for a surface, or a commit_timer_exists protocol error will be generated.